@@ -6,22 +6,22 @@ from django.template import Template, Context
 
 
 class DjfrontendStaticTest(LiveServerTestCase):
-    
+
     """
     Ensure the files actually exist.
     """
 
     # Change settings until StaticLiveServerCase in 1.7!
     settings.DEBUG = True
-    
+
     def test_djfrontend_h5bp_css(self):
         file = self.client.get(self.live_server_url + '/static/djfrontend/css/h5bp/%s/h5bp.css' % DJFRONTEND_H5BP_CSS_DEFAULT)
         self.assertEqual(file.status_code, 200)
-    
+
     def test_djfrontend_normalize(self):
         file = self.client.get(self.live_server_url + '/static/djfrontend/css/normalize/%s/normalize.css' % DJFRONTEND_NORMALIZE_DEFAULT)
         self.assertEqual(file.status_code, 200)
-        
+
     def test_djfrontend_fontawesome(self):
         file = self.client.get(self.live_server_url + '/static/djfrontend/css/fontawesome/%s/font-awesome.css' % DJFRONTEND_FONTAWESOME_DEFAULT)
         file_min = self.client.get(self.live_server_url + '/static/djfrontend/css/fontawesome/%s/font-awesome.min.css' % DJFRONTEND_FONTAWESOME_DEFAULT)
@@ -35,7 +35,7 @@ class DjfrontendStaticTest(LiveServerTestCase):
         self.assertEqual(file_font_svg.status_code, 200)
         self.assertEqual(file_font_ttf.status_code, 200)
         self.assertEqual(file_font_woff.status_code, 200)
-        
+
     def test_djfrontend_modernizr(self):
         file = self.client.get(self.live_server_url + '/static/djfrontend/js/modernizr/%s/modernizr.js' % DJFRONTEND_MODERNIZR_DEFAULT)
         file_min = self.client.get(self.live_server_url + '/static/djfrontend/js/modernizr/%s/modernizr.min.js' % DJFRONTEND_MODERNIZR_DEFAULT)
@@ -62,8 +62,14 @@ class DjfrontendStaticTest(LiveServerTestCase):
 
     def test_djfrontend_jquery_datatables_css(self):
         file = self.client.get(self.live_server_url + '/static/djfrontend/css/jquery/jquery.dataTables/%s/jquery.dataTables.css' % DJFRONTEND_JQUERY_DATATABLES_VERSION_DEFAULT)
+        file_min = self.client.get(self.live_server_url + '/static/djfrontend/css/jquery/jquery.dataTables/%s/jquery.dataTables.min.css' % DJFRONTEND_JQUERY_DATATABLES_VERSION_DEFAULT)
         self.assertEqual(file.status_code, 200)
-        
+        self.assertEqual(file.status_code, 200)
+
+    def test_djfrontend_jquery_datatables_themeroller(self):
+        file = self.client.get(self.live_server_url + '/static/djfrontend/css/jquery/jquery.dataTables/%s/jquery.dataTables_themeroller.css' % DJFRONTEND_JQUERY_DATATABLES_VERSION_DEFAULT)
+        self.assertEqual(file.status_code, 200)
+
     def test_djfrontend_jquery_formset(self):
         file = self.client.get(self.live_server_url + '/static/djfrontend/js/jquery/jquery.formset/%s/jquery.formset.js' % DJFRONTEND_JQUERY_FORMSET_DEFAULT)
         file_min = self.client.get(self.live_server_url + '/static/djfrontend/js/jquery/jquery.formset/%s/jquery.formset.min.js' % DJFRONTEND_JQUERY_FORMSET_DEFAULT)
@@ -75,13 +81,13 @@ class DjfrontendStaticTest(LiveServerTestCase):
         file_min = self.client.get(self.live_server_url + '/static/djfrontend/js/jquery/jquery.scrollTo/%s/jquery.scrollTo.min.js' % DJFRONTEND_JQUERY_SCROLLTO_DEFAULT)
         self.assertEqual(file.status_code, 200)
         self.assertEqual(file_min.status_code, 200)
-        
+
     def test_djfrontend_jquery_smoothscroll(self):
         file = self.client.get(self.live_server_url + '/static/djfrontend/js/jquery/jquery.smooth-scroll/%s/jquery.smooth-scroll.js' % DJFRONTEND_JQUERY_SMOOTHSCROLL_DEFAULT)
         file_min = self.client.get(self.live_server_url + '/static/djfrontend/js/jquery/jquery.smooth-scroll/%s/jquery.smooth-scroll.min.js' % DJFRONTEND_JQUERY_SMOOTHSCROLL_DEFAULT)
         self.assertEqual(file.status_code, 200)
         self.assertEqual(file_min.status_code, 200)
-        
+
     def test_djfrontend_twbs_css(self):
         file = self.client.get(self.live_server_url + '/static/djfrontend/css/twbs/%s/bootstrap.css' % DJFRONTEND_TWBS_VERSION_DEFAULT)
         file_min = self.client.get(self.live_server_url + '/static/djfrontend/css/twbs/%s/bootstrap.min.css' % DJFRONTEND_TWBS_VERSION_DEFAULT)
@@ -134,11 +140,11 @@ class DjfrontendStaticTest(LiveServerTestCase):
 
 
 class DjfrontendDefaultTestCase(TestCase):
-    
+
     """
     Ensure the default values are being returned.
     """
-    
+
     def test_djfrontend_h5bp_html(self):
         attr = 'lang="%s"' % DJFRONTEND_H5BP_HTML_DEFAULT
         t = Template(
@@ -146,21 +152,21 @@ class DjfrontendDefaultTestCase(TestCase):
             "{% djfrontend_h5bp_html %}"
         ).render(Context())
         self.assertTrue(attr in t)
-    
+
     def test_djfrontend_h5bp_css(self):
         t = Template(
             "{% load djfrontend %}"
             "{% djfrontend_h5bp_css %}"
         ).render(Context())
         self.assertTrue(DJFRONTEND_H5BP_CSS_DEFAULT in t)
-        
+
     def test_djfrontend_normalize(self):
         t = Template(
             "{% load djfrontend %}"
             "{% djfrontend_normalize %}"
         ).render(Context())
         self.assertTrue(DJFRONTEND_NORMALIZE_DEFAULT in t)
-        
+
     def test_djfrontend_fontawesome(self):
         t = Template(
             "{% load djfrontend %}"
@@ -174,92 +180,92 @@ class DjfrontendDefaultTestCase(TestCase):
             "{% djfrontend_modernizr %}"
         ).render(Context())
         self.assertTrue(DJFRONTEND_MODERNIZR_DEFAULT in t)
-        
+
     def test_djfrontend_jquery(self):
         t = Template(
             "{% load djfrontend %}"
             "{% djfrontend_jquery %}"
         ).render(Context())
         self.assertTrue(DJFRONTEND_JQUERY_DEFAULT in t)
-        
+
     def test_djfrontend_jqueryui(self):
         t = Template(
             "{% load djfrontend %}"
             "{% djfrontend_jqueryui %}"
         ).render(Context())
         self.assertTrue(DJFRONTEND_JQUERYUI_DEFAULT in t)
-        
+
     def test_djfrontend_jquery_datatables(self):
         t = Template(
             "{% load djfrontend %}"
             "{% djfrontend_jquery_datatables %}"
         ).render(Context())
         self.assertTrue(DJFRONTEND_JQUERY_DATATABLES_VERSION_DEFAULT in t)
-        
+
     def test_djfrontend_jquery_datatables_css(self):
         t = Template(
             "{% load djfrontend %}"
             "{% djfrontend_jquery_datatables_css %}"
         ).render(Context())
         self.assertTrue(DJFRONTEND_JQUERY_DATATABLES_VERSION_DEFAULT in t)
-        
+
     def test_djfrontend_jquery_formset(self):
         t = Template(
             "{% load djfrontend %}"
             "{% djfrontend_jquery_formset %}"
         ).render(Context())
         self.assertTrue(DJFRONTEND_JQUERY_FORMSET_DEFAULT in t)
-        
+
     def test_djfrontend_jquery_scrollto(self):
         t = Template(
             "{% load djfrontend %}"
             "{% djfrontend_jquery_scrollto %}"
         ).render(Context())
         self.assertTrue(DJFRONTEND_JQUERY_SCROLLTO_DEFAULT in t)
-        
+
     def test_djfrontend_jquery_smoothscroll(self):
         t = Template(
             "{% load djfrontend %}"
             "{% djfrontend_jquery_smoothscroll %}"
         ).render(Context())
         self.assertTrue(DJFRONTEND_JQUERY_SMOOTHSCROLL_DEFAULT in t)
-        
+
     def test_djfrontend_twbs_css(self):
         t = Template(
             "{% load djfrontend %}"
             "{% djfrontend_twbs_css %}"
         ).render(Context())
         self.assertTrue(DJFRONTEND_TWBS_VERSION_DEFAULT in t)
-        
+
     def test_djfrontend_twbs_theme_css(self):
         t = Template(
             "{% load djfrontend %}"
             "{% djfrontend_twbs_theme_css %}"
         ).render(Context())
         self.assertTrue(DJFRONTEND_TWBS_VERSION_DEFAULT in t)
-        
+
     def test_djfrontend_twbs_js(self):
         t = Template(
             "{% load djfrontend %}"
             "{% djfrontend_twbs_js %}"
         ).render(Context())
         self.assertTrue(DJFRONTEND_TWBS_VERSION_DEFAULT in t)
-        
+
     def test_djfrontend_twbs_js_popover(self):
         t = Template(
             "{% load djfrontend %}"
             "{% djfrontend_twbs_js files='popover' %}"
         ).render(Context())
-        self.assertTrue('popover.js' in t)    
+        self.assertTrue('popover.js' in t)
         self.assertTrue('tooltip.js' in t)
 
 
 class DjfrontendSettingsTestCase(TestCase):
-    
+
     """
     Ensure the settings override the defaults.
     """
-    
+
     def test_djfrontend_h5bp_html(self):
         attr = 'lang="%s"' % DJFRONTEND_H5BP_HTML_DEFAULT
         settings.DJFRONTEND_H5BP_HTML = 'fr'
@@ -268,7 +274,7 @@ class DjfrontendSettingsTestCase(TestCase):
             "{% djfrontend_h5bp_html %}"
         ).render(Context())
         self.assertFalse(attr in t)
-        
+
     def test_djfrontend_h5bp_css(self):
         settings.DJFRONTEND_H5BP_CSS = '0.0.0'
         t = Template(
@@ -276,7 +282,7 @@ class DjfrontendSettingsTestCase(TestCase):
             "{% djfrontend_h5bp_css %}"
         ).render(Context())
         self.assertFalse(DJFRONTEND_H5BP_CSS_DEFAULT in t)
-        
+
     def test_djfrontend_normalize(self):
         settings.DJFRONTEND_NORMALIZE = '0.0.0'
         t = Template(
@@ -284,7 +290,7 @@ class DjfrontendSettingsTestCase(TestCase):
             "{% djfrontend_normalize %}"
         ).render(Context())
         self.assertFalse(DJFRONTEND_NORMALIZE_DEFAULT in t)
-        
+
     def test_djfrontend_fontawesome(self):
         settings.DJFRONTEND_FONTAWESOME = '0.0.0'
         t = Template(
@@ -300,7 +306,7 @@ class DjfrontendSettingsTestCase(TestCase):
             "{% djfrontend_modernizr %}"
         ).render(Context())
         self.assertFalse(DJFRONTEND_MODERNIZR_DEFAULT in t)
-    
+
     def test_djfrontend_jquery(self):
         settings.DJFRONTEND_JQUERY = '0.0.0'
         t = Template(
@@ -308,7 +314,7 @@ class DjfrontendSettingsTestCase(TestCase):
             "{% djfrontend_jquery %}"
         ).render(Context())
         self.assertFalse(DJFRONTEND_JQUERY_DEFAULT in t)
-    
+
     def test_djfrontend_jqueryui(self):
         settings.DJFRONTEND_JQUERYUI = '0.0.0'
         t = Template(
@@ -316,7 +322,7 @@ class DjfrontendSettingsTestCase(TestCase):
             "{% djfrontend_jqueryui %}"
         ).render(Context())
         self.assertFalse(DJFRONTEND_JQUERYUI_DEFAULT in t)
-    
+
     def test_djfrontend_jquery_datatables(self):
         settings.DJFRONTEND_JQUERY_DATATABLES = '0.0.0'
         t = Template(
@@ -324,7 +330,7 @@ class DjfrontendSettingsTestCase(TestCase):
             "{% djfrontend_jquery_datatables %}"
         ).render(Context())
         self.assertFalse(DJFRONTEND_JQUERY_DATATABLES_VERSION_DEFAULT in t)
-    
+
     def test_djfrontend_jquery_datatables_css(self):
         settings.DJFRONTEND_JQUERY_DATATABLES_CSS = '0.0.0'
         t = Template(
@@ -332,7 +338,7 @@ class DjfrontendSettingsTestCase(TestCase):
             "{% djfrontend_jquery_datatables_css %}"
         ).render(Context())
         self.assertFalse(DJFRONTEND_JQUERY_DATATABLES_VERSION_DEFAULT in t)
-    
+
     def test_djfrontend_jquery_formset(self):
         settings.DJFRONTEND_JQUERY_FORMSET = '0.0.0'
         t = Template(
@@ -340,7 +346,7 @@ class DjfrontendSettingsTestCase(TestCase):
             "{% djfrontend_jquery_formset %}"
         ).render(Context())
         self.assertFalse(DJFRONTEND_JQUERY_FORMSET_DEFAULT in t)
-    
+
     def test_djfrontend_jquery_scrollto(self):
         settings.DJFRONTEND_JQUERY_SCROLLTO = '0.0.0'
         t = Template(
@@ -348,7 +354,7 @@ class DjfrontendSettingsTestCase(TestCase):
             "{% djfrontend_jquery_scrollto %}"
         ).render(Context())
         self.assertFalse(DJFRONTEND_JQUERY_SCROLLTO_DEFAULT in t)
-    
+
     def test_djfrontend_jquery_smoothscroll(self):
         settings.DJFRONTEND_JQUERY_SMOOTHSCROLL = '0.0.0'
         t = Template(
@@ -356,7 +362,7 @@ class DjfrontendSettingsTestCase(TestCase):
             "{% djfrontend_jquery_smoothscroll %}"
         ).render(Context())
         self.assertFalse(DJFRONTEND_JQUERY_SMOOTHSCROLL_DEFAULT in t)
-    
+
     def test_djfrontend_twbs_css(self):
         settings.DJFRONTEND_TWBS_CSS = '0.0.0'
         t = Template(
@@ -364,7 +370,7 @@ class DjfrontendSettingsTestCase(TestCase):
             "{% djfrontend_twbs_css %}"
         ).render(Context())
         self.assertFalse(DJFRONTEND_TWBS_VERSION_DEFAULT in t)
-    
+
     def test_djfrontend_twbs_theme_css(self):
         settings.DJFRONTEND_TWBS_THEME_CSS = '0.0.0'
         t = Template(
@@ -372,7 +378,7 @@ class DjfrontendSettingsTestCase(TestCase):
             "{% djfrontend_twbs_theme_css %}"
         ).render(Context())
         self.assertFalse(DJFRONTEND_TWBS_VERSION_DEFAULT in t)
-    
+
     def test_djfrontend_twbs_js(self):
         settings.DJFRONTEND_TWBS_JS_VERSION = '0.0.0'
         t = Template(
@@ -383,11 +389,11 @@ class DjfrontendSettingsTestCase(TestCase):
 
 
 class DjfrontendSettingsGranularityTestCase(TestCase):
-    
+
     """
     Ensure the template tag argument is the final override.
     """
-    
+
     def test_djfrontend_h5bp_html(self):
         attr_default = 'lang="%s"' % DJFRONTEND_H5BP_HTML_DEFAULT
         attr = 'lang="de"'
@@ -398,7 +404,7 @@ class DjfrontendSettingsGranularityTestCase(TestCase):
         ).render(Context())
         self.assertFalse(attr_default in t)
         self.assertTrue(attr in t)
-        
+
     def test_djfrontend_h5bp_css(self):
         settings.DJFRONTEND_H5BP_CSS = '0.0.0'
         t = Template(
@@ -407,7 +413,7 @@ class DjfrontendSettingsGranularityTestCase(TestCase):
         ).render(Context())
         self.assertFalse(DJFRONTEND_H5BP_CSS_DEFAULT in t)
         self.assertTrue('x.x.x' in t)
-        
+
     def test_djfrontend_normalize(self):
         settings.DJFRONTEND_NORMALIZE = '0.0.0'
         t = Template(
@@ -416,7 +422,7 @@ class DjfrontendSettingsGranularityTestCase(TestCase):
         ).render(Context())
         self.assertFalse(DJFRONTEND_NORMALIZE_DEFAULT in t)
         self.assertTrue('x.x.x' in t)
-    
+
     def test_djfrontend_fontawesome(self):
         settings.DJFRONTEND_FONTAWESOME = '0.0.0'
         t = Template(
@@ -471,6 +477,15 @@ class DjfrontendSettingsGranularityTestCase(TestCase):
         self.assertFalse(DJFRONTEND_JQUERY_DATATABLES_VERSION_DEFAULT in t)
         self.assertTrue('x.x.x' in t)
 
+    def test_djfrontend_jquery_datatables_themeroller(self):
+        settings.DJFRONTEND_JQUERY_DATATABLES_THEMEROLLER = '0.0.0'
+        t = Template(
+            "{% load djfrontend %}"
+            "{% djfrontend_jquery_datatables_css 'x.x.x' %}"
+        ).render(Context())
+        self.assertFalse(DJFRONTEND_JQUERY_DATATABLES_VERSION_DEFAULT in t)
+        self.assertTrue('x.x.x' in t)
+
     def test_djfrontend_jquery_formset(self):
         settings.DJFRONTEND_JQUERY_FORMSET = '0.0.0'
         t = Template(
@@ -523,4 +538,4 @@ class DjfrontendSettingsGranularityTestCase(TestCase):
             "{% djfrontend_twbs_js 'x.x.x' %}"
         ).render(Context())
         self.assertFalse(DJFRONTEND_TWBS_VERSION_DEFAULT in t)
-        self.assertTrue('x.x.x' in t)
\ No newline at end of file
+        self.assertTrue('x.x.x' in t)
